@@ -239,7 +239,12 @@ class RegFieldSpec:
         self.valDict[fieldVal.name] = fieldVal
 
     def getFieldMaskMacro(self, spacing = 0):
-        ret = self.reg.device.prefix.upper() +"_"+self.reg.pattern.replace('$n','X').upper()+"_"+self.name.upper() +"_FIELD_MASK"
+        print(self.reg.pattern)
+
+        if(self.flat):
+            ret = self.reg.device.prefix.upper() +"_"+self.name.upper() +"_FIELD_MASK"
+        else :
+            ret = self.reg.device.prefix.upper() +"_"+self.reg.pattern.replace('$n','X').upper()+"_"+self.name.upper() +"_FIELD_MASK"
 
         if spacing > 0:
             spaces = spacing - len(ret)
@@ -247,7 +252,10 @@ class RegFieldSpec:
         return ret
     
     def getFieldOffsetkMacro(self, spacing = 0):
-        ret = self.reg.device.prefix.upper() +"_"+self.reg.pattern.replace('$n','X').upper()+"_"+self.name.upper() +"_FIELD_OFFSET"
+        if(self.flat):
+            ret = self.reg.device.prefix.upper() +"_"+self.name.upper() +"_FIELD_OFFSET"
+        else:
+            ret = self.reg.device.prefix.upper() +"_"+self.reg.pattern.replace('$n','X').upper()+"_"+self.name.upper() +"_FIELD_OFFSET"
 
         if spacing > 0:
             spaces = spacing - len(ret)
@@ -255,7 +263,11 @@ class RegFieldSpec:
         return ret
 
     def getFieldFlagMacro(self, spacing = 0):
-        ret = self.reg.device.prefix.upper() +"_"+ self.reg.pattern.replace('$n','X').upper()+"_"+self.name.upper()
+
+        if(self.flat):
+            ret = self.reg.device.prefix.upper() +"_"+self.name.upper()
+        else: 
+            ret = self.reg.device.prefix.upper() +"_"+ self.reg.pattern.replace('$n','X').upper()+"_"+self.name.upper()
 
         if spacing > 0:
             spaces = spacing - len(ret)
@@ -678,6 +690,7 @@ class DeviceSpec:
                         expandedRegs.append(expandedItem)
 
                 else:
+                    regItemRaw['pattern'] = regItemRaw['reg_name']
                     expandedRegs.append(regItemRaw)
                     
                 for idx, regItem in enumerate(expandedRegs): 
