@@ -197,8 +197,21 @@ class GattCharacteristic(object):
     
     def loadUri(self,uri):
         print("Pulling " + uri)
-        self.url = "https://www.bluetooth.com/wp-content/uploads/Sitecore-Media-Library/Gatt/Xml/Characteristics/" + uri + ".xml"
-        root = getXml(self.url)
+
+        #self.url = "https://www.bluetooth.com/wp-content/uploads/Sitecore-Media-Library/Gatt/Xml/Characteristics/" + uri + ".xml"
+                
+        #
+        #   Bluetoot SIG stopped publishing XML files, this is a temporary workaround:
+        #
+        self.url = "https://gitlab.com/uprev/public/mrt/gatt-xml/-/raw/master/" + uri + ".xml"
+
+        try:
+            root = getXml(self.url)
+        except:
+
+            print("Failed to get " + self.url)
+
+
         self.uri = uri
         self.isStandard = True
 
@@ -223,7 +236,14 @@ class GattCharacteristic(object):
         self.desc = self.desc.replace('\n','').replace('\t','')
     
     def loadServiceUri(self, uri):
-        url = "https://www.bluetooth.com/wp-content/uploads/Sitecore-Media-Library/Gatt/Xml/Services/" + uri + ".xml"
+
+        #url = "https://www.bluetooth.com/wp-content/uploads/Sitecore-Media-Library/Gatt/Xml/Services/" + uri + ".xml"
+                
+        #
+        #   Bluetoot SIG stopped publishing XML files, this is a temporary workaround:
+        #
+        url = "https://gitlab.com/uprev/public/mrt/gatt-xml/-/raw/master/" + uri + ".xml"
+        
         root = getXml(url)
  
         xmlChar = root.find('./Characteristics/Characteristic[@type=\"' + self.uri + '\"]')
@@ -342,7 +362,12 @@ class GattService(object):
     
     def loadUri(self, uri):
         print("Pulling " + uri)
-        self.url = "https://www.bluetooth.com/wp-content/uploads/Sitecore-Media-Library/Gatt/Xml/Services/" + uri + ".xml"
+        #self.url = "https://www.bluetooth.com/wp-content/uploads/Sitecore-Media-Library/Gatt/Xml/Services/" + uri + ".xml"
+        
+        #
+        #   Bluetoot SIG stopped publishing XML files, this is a temporary workaround:
+        #
+        self.url = "https://gitlab.com/uprev/public/mrt/gatt-xml/-/raw/master/" + uri + ".xml"
         root = getXml(self.url)
         self.isStandard = True
         self.uri = uri
