@@ -62,7 +62,7 @@ class Submodule:
         self.repo_name = url.split('/')[-1].replace(".git","")
         self.yaml = {}  
         self.repo = None
-        self.submodrepo = Repo(self.url, True, False)
+        self.submodrepo = Repo(self.url, True, False, False)
 
     def checkFor(self,mods):
         global relativePath
@@ -92,6 +92,11 @@ class Submodule:
         except:
            print( "Couldnt Load mrt.yml for " + self.name)
 
+    def loadRootYaml(self):
+        mrtYaml = self.submodrepo.getRootYaml()
+        self.loadYaml(mrtYaml)
+
+
     def getOtherYaml(self, file):
 
         yamlText = ""
@@ -287,6 +292,11 @@ class RepoDirectory:
         for mod in self.mods.values():
             os.makedirs(path+"/"+mod.name,exist_ok=True)
 
+            if os.path.isdir(mod.path + "/doc"):
+                shutil.copytree(mod.path + "/doc", path+"/"+mod.name+"/doc")
+
+
+            
             for file in glob.glob(mod.path+"/*.rst"):
                 fileName = shutil.copy(file, path+"/"+mod.name+"/")  
 
@@ -337,26 +347,34 @@ class RepoDirectory:
 
             fileTxt += "\n"
 
-        if not lvl == 0:
+        #Add Unit test option to main menu
+        if lvl == 0:
+            fileTxt += "config ENABLE_UNITTEST\n"
+            fileTxt += "\t bool \"UnitTest\"\n"
+            fileTxt += "\t default n\n"
+
+        else:
             fileTxt += "endmenu\n\n"
+
         
         return fileTxt
 
-
 class Repo:
-    def __init__(self, path :str, remote = False, createdir=True):
-
+    def __init__(self, path :str, remote = False, createdir=True, fetchDefaultBranch = True):
+    
         self.url = path
         self.path = path
         self.mods =[]
         self.isRemote = remote
-        self.rootYaml = {}
+        self.rootYaml = None
         normalUrl = path.replace(':','/')
         nodes = normalUrl.split('/')
         self.name = nodes[-1].replace(".git","")
         self.host = ''
         self.isGroup = False
-        self.subpath = ""      
+        self.subpath = ""     
+        self.default_branch = "master" 
+        self.mrtManifestPath = ""
 
         if "bitbucket.org" in path:
             self.host = 'bitbucket'
@@ -375,6 +393,9 @@ class Repo:
                 self.isGroup = True
                 self.subpath = self.path.replace("https://gitlab.com/","")
 
+        if not self.name == "" and not self.isGroup and fetchDefaultBranch:
+            self.getDefaultBranch()
+
         self.dir = None 
         if createdir:
             self.dir = RepoDirectory("root",0)
@@ -399,12 +420,15 @@ class Repo:
         for mod in self.mods:
             mod.checkFor(repo.mods)
     
-    def getRootYaml(self):
+    def getRootYaml(self, url = ""):
         
         yamlText = ""
         yamlObj = {}
 
-        yamlText = self.getFileText('mrt.yml')
+        if url == "":
+            yamlText = self.getFileText('mrt.yml')
+        else:
+            yamlText = getRemoteFileText(url,'mrt.yml')
         
         
         try:
@@ -419,8 +443,11 @@ class Repo:
 
     def gatherModuleYamls(self):
         dict_yaml = {}
+        modules = []
         for mod in self.mods:
-            dict_yaml[mod.name] = mod.getYaml()
+            modules.append(mod.getYaml())
+        
+        dict_yaml['modules'] = modules
         
         return dict_yaml
         
@@ -440,7 +467,7 @@ class Repo:
                 escapedSubPath = self.subpath.replace("/", "%2f")
 
 
-                apiCall = 'https://{0}.com/{1}/{2}/projects?include_subgroups=true'.format(self.host, api, escapedSubPath)
+                apiCall = 'https://{0}.com/{1}/{2}/projects?include_subgroups=true&order_by=created_at&per_page=10000'.format(self.host, api, escapedSubPath)
                 resp = requests.get(apiCall)
 
                 if resp.status_code == 200:
@@ -479,32 +506,41 @@ class Repo:
 
                             nodes = modPath.split("/")
 
-                            #ignore things outside of Module path
-                            if(nodes[0] == "Modules"):
+                            #ignore any project that had "mrt-ignore" tag
+                            if not"mrt-ignore" in mod["tag_list"]:
                                 modUrl = mod["http_url_to_repo"]
                                 newSubMod = Submodule(modPath, modUrl)
-                                mrtYaml = newSubMod.submodrepo.getRootYaml()
-                                newSubMod.loadYaml(mrtYaml)
+                                newSubMod.submodrepo.default_branch = mod["default_branch"]
                                 self.mods.append(newSubMod)
+
+                    threads = []
+                    for mod in self.mods:
+                        threads.append(Thread(target=mod.loadRootYaml))
                     
-                
+                    for thread in threads:
+                        thread.start()
+
+                    for thread in threads:
+                        thread.join()
+
+
+                else:
+                    data = self.getFileText('.gitmodules').replace('\r', '').replace('\n', '').replace('\t', '')
+                    #read in all modules
+                    regex = re.compile(r'\[(.*?)].*?path = (.*?)url = (.*?\.git)')
+                    modules = regex.findall(data)
+                    for mod in modules:
+                        if(mod[1] != "Config"):
+                            self.mods.append(Submodule(mod[1], mod[2]))
             else:
-                data = self.getFileText('.gitmodules').replace('\r', '').replace('\n', '').replace('\t', '')
-                #read in all modules
-                regex = re.compile(r'\[(.*?)].*?path = (.*?)url = (.*?\.git)')
-                modules = regex.findall(data)
-                for mod in modules:
-                    if(mod[1] != "Config"):
+                if os.path.isfile(self.path + "/.gitmodules"):
+                    file = open(self.path + "/.gitmodules", "r")
+                    data = file.read().replace('\r', '').replace('\n', '').replace('\t', '')
+                    #read in all modules
+                    regex = re.compile(r'\[(.*?)].*?path = (.*?)url = (.*?\.git)')
+                    modules = regex.findall(data)
+                    for mod in modules:
                         self.mods.append(Submodule(mod[1], mod[2]))
-        else:
-            if os.path.isfile(self.path + "/.gitmodules"):
-                file = open(self.path + "/.gitmodules", "r")
-                data = file.read().replace('\r', '').replace('\n', '').replace('\t', '')
-                #read in all modules
-                regex = re.compile(r'\[(.*?)].*?path = (.*?)url = (.*?\.git)')
-                modules = regex.findall(data)
-                for mod in modules:
-                    self.mods.append(Submodule(mod[1], mod[2]))
         
         
         for mod in self.mods:
@@ -522,11 +558,11 @@ class Repo:
             req_url = ""
 
             if(self.host== 'github'):
-                req_url = "https://raw.githubusercontent.com/" + self.account + "/" + self.name + "/master/" + file
+                req_url = "https://raw.githubusercontent.com/" + self.account + "/" + self.name + "/" + self.default_branch + "/" + file
             elif(self.host == 'bitbucket'):
-                req_url = "https://bitbucket.org/" + self.account + "/" + self.name + "/raw/master/" + file
+                req_url = "https://bitbucket.org/" + self.account + "/" + self.name + "/raw/" +self.default_branch + "/" + file
             elif(self.host == 'gitlab'):
-                req_url = self.path.replace(".git","") + "/-/raw/master/" + file
+                req_url = self.path.replace(".git","") + "/-/raw/" + self.default_branch+ "/" + file
   
             
             try:
@@ -588,6 +624,33 @@ class Repo:
         os.chdir(prev_path)
         mod.exists = False
     
+    def getDefaultBranch(self):
+
+        try:
+
+            if self.isRemote:
+                git_ls_remote_cmd = ['git', 'ls-remote', '--symref', self.url, 'HEAD']
+                awk_cmd = ["awk", "-F[/\\t]", "NR == 1 {print $3}"]
+                git_ls_remote_output = subprocess.check_output(git_ls_remote_cmd)
+
+                result = subprocess.check_output(awk_cmd, input=git_ls_remote_output)
+
+                branch = result.decode().strip()
+                self.default_branch = branch
+            else:
+                branch = subprocess.check_output("git remote show " + self.path + " | sed -n '/HEAD branch/s/.*: //p'", shell=True)
+
+                self.default_branch = branch
+        except:
+
+            if(self.isRemote):
+                print("Couldnt get default branch for " + self.name + " from " + self.url)
+            else:
+                print("Couldnt get default branch for local repo: " + self.name )
+
+
+        return self.default_branch
+    
     def getKConfigString(self):
         out = self.dir.getKConfigString(0) 
 
