@@ -21,7 +21,7 @@
 /**
  * @brief Called after GATT Server is intialized
  */
-void ${obj.prefix}_svc_post_init_handler(void)
+void ${obj.prefix}_svc_post_registration_handler(void)
 {
 % for char in obj.chars:
     %if hasattr(char, 'default'):
