@@ -31,10 +31,27 @@ typedef struct{
 /* Exported constants --------------------------------------------------------*/
 extern ${obj.name.lower()}_profile_t ${obj.name}_profile;
 /* Exported functions ------------------------------------------------------- */
-mrt_status_t ${obj.name.lower()}_profile_init(void);
 
+/**
+ * @brief initialize profile
+ * @param ctx ptr to context (defined by platform)
+ * @returns status
+ */
+mrt_status_t ${obj.name.lower()}_profile_init(void* ctx);
+
+/**
+ * @brief Registers services in profile
+ * @returns status
+ */
 mrt_status_t ${obj.name.lower()}_profile_register(void);
 
+/**
+ * @brief Handles events for profile and dispatches to appropriate service/characteristic handler
+ * @param evt ptr to event struct 
+ * @returns status
+*/
+mrt_status_t ${obj.name.lower()}_profile_handle_evt(mrt_gatt_evt_t* evt);
+
 /*user-block-functions-start*/
 /*user-block-functions-end*/
 
