@@ -12,7 +12,7 @@ extern "C"
 
 /* Includes ------------------------------------------------------------------*/
 %if obj.profile.platform == 'mrt':
-#include "Utilities/Interfaces/GattServer/gatt_server.h"
+#include "Utilities/Interfaces/GattInterface/mrt_gatt_interface.h"
 %else:
 #include "../interface/mrt_gatt_interface.h"
 %endif 
@@ -23,7 +23,7 @@ extern "C"
     % if len(char.vals) > 0:
 /* ${char.name} Values */
         % for val in char.vals:
-    #define ${t.padAfter(obj.prefix +"_"+char.name + "_"+val.name , 12).upper()} ${"0x{:04x}".format(val.value)}   // ${val.desc}
+#define ${t.padAfter(obj.prefix +"_"+char.name + "_"+val.name , 12).upper()} ${"0x{:04x}".format(val.value)}   // ${val.desc}
         % endfor
 
     %endif
@@ -34,9 +34,9 @@ extern "C"
 % for char in obj.chars:
 %if (char.type != 'string'):
 %if (char.arrayLen > 1):
-    ${t.padAfter("typedef {0}*".format(t.cTypeDict[char.type]), 45)}${"{0}_{1}_t;".format(obj.prefix,char.name.lower())}
+${t.padAfter("typedef {0}*".format(t.cTypeDict[char.type]), 45)}${"{0}_{1}_t;".format(obj.prefix,char.name.lower())}
 %else:
-    ${t.padAfter("typedef {0}".format(t.cTypeDict[char.type]), 45)}${"{0}_{1}_t;".format(obj.prefix,char.name.lower())}
+${t.padAfter("typedef {0}".format(t.cTypeDict[char.type]), 45)}${"{0}_{1}_t;".format(obj.prefix,char.name.lower())}
 %endif
 %endif
 % endfor
@@ -67,14 +67,15 @@ void ${obj.prefix}_svc_register();
 /* */
 % for char in obj.chars:
 % if char.perm.lower() != 'w':
-%if char.type == 'string':
-${ t.padAfter("#define {0}_set_{1}(val)".format(obj.prefix,char.name.lower()) , 45)}${"mrt_gatt_update_char_val(&{0}_svc.m{1}, (uint8_t*) val, strlen(val))".format(obj.prefix, t.camelCase(char.name))}
-%if  (char.arrayLen > 1):
-${ t.padAfter("#define {0}_set_{1}(val,len)".format(obj.prefix,char.name.lower()) , 45)}${"mrt_gatt_update_char_val(&{0}_svc.m{1}, (uint8_t*) val, len)".format(obj.prefix, t.camelCase(char.name))}
-%else:
-${ t.padAfter("#define {0}_set_{1}(val)".format(obj.prefix,char.name.lower()) , 45)}${"mrt_gatt_update_char_val(&{0}_svc.m{1}, (uint8_t*) val, {2})".format(obj.prefix, t.camelCase(char.name),char.size(), char.name.lower())}
-%endif
-%endif
+    %if char.type == 'string':
+${t.padAfter("#define {0}_set_{1}(val)".format(obj.prefix,char.name.lower()) , 45)}${"mrt_gatt_update_char_val(&{0}_svc.m{1}, (uint8_t*) val, strlen(val))".format(obj.prefix, t.camelCase(char.name))}
+    %else:
+        %if  (char.arrayLen > 1):
+${t.padAfter("#define {0}_set_{1}(val,len)".format(obj.prefix,char.name.lower()) , 45)}${"mrt_gatt_update_char_val(&{0}_svc.m{1}, (uint8_t*) val, len)".format(obj.prefix, t.camelCase(char.name))}
+        %else:
+${t.padAfter("#define {0}_set_{1}(val)".format(obj.prefix,char.name.lower()) , 45)}${"mrt_gatt_update_char_val(&{0}_svc.m{1}, (uint8_t*) val, {2})".format(obj.prefix, t.camelCase(char.name),char.size(), char.name.lower())}
+        %endif
+    %endif
 %endif
 % endfor
 
@@ -97,7 +98,7 @@ ${t.padAfter("#define {0}_{1}_cache_valid()".format(obj.prefix,char.name.lower()
 % endfor
 
 /* Handlers ------------------------------------------------------------------*/
-void ${obj.prefix}_svc_post_init_handler();
+void ${obj.prefix}_svc_post_registration_handler();
 
 % for char in obj.chars:
 ${"mrt_status_t {0}_{1}_handler(mrt_gatt_evt_t* event);".format(obj.prefix,char.name.lower())}
